from setuptools import setup
import re


with open("./AlbertUnruhUtils/__init__.py") as f:
    file = f.read()

version = re.search(
    r"^__version__\s*=\s*[\'\"]([^\'\"]*)[\'\"]", file, re.MULTILINE
).group(1)
url = re.search(r"^__url__\s*=\s*[\'\"]([^\'\"]*)[\'\"]", file, re.MULTILINE).group(1)
license = re.search(  # noqa
    r"^__license__\s*=\s*[\'\"]([^\'\"]*)[\'\"]", file, re.MULTILINE
).group(1)
author = re.search(
    r"^__author__\s*=\s*[\'\"]([^\'\"]*)[\'\"]", file, re.MULTILINE
).group(1)
description = re.search(
    r"^__description__\s*=\s*[\'\"]([^\'\"]*)[\'\"]", file, re.MULTILINE
).group(1)


# not in setup.cfg for GitHub's Dependency-Graph
install_requires = [
    "redis~=4.1.0",
    "aioredis~=2.0.1",
]


setup(
    version=version,
    url=url,
    license=license,
    author=author,
    description=description,
    install_requires=install_requires,
)



__author__ = "AlbertUnruh"
__url__ = "https://github.com/AlbertUnruh/AlbertUnruhUtils.py"
__license__ = "MIT"
__copyright__ = f"(c) {__author__}"
__version__ = "2022.01.08.004"  # pattern: 'YYYY.MM.DD.{increment:3}'
__description__ = "A collection of utils written in Python."

from . import asynchronous
from . import config
from . import ratelimit

from .config import *
from .ratelimit import *
